
# Slot: in location




URI: [ks:in_location](https://w3id.org/linkml/tests/kitchen_sink/in_location)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Place](Place.md)

## Parents


## Children


## Used by

 * [BirthEvent](BirthEvent.md)
 * [MarriageEvent](MarriageEvent.md)
 * [MedicalEvent](MedicalEvent.md)
 * [WithLocation](WithLocation.md)
